@@ -39,7 +39,6 @@
 #include <pan/data/article-cache.h>
 #include <pan/data/encode-cache.h>
 #include <pan/data/data.h>
-
 #include <pan/data-impl/data-io.h>
 #include <pan/data-impl/article-filter.h>
 #include <pan/data-impl/rules-filter.h>
@@ -76,6 +75,7 @@ namespace pan
     **/
 
     public:
+      /* The ProfilesImpl will own and destruct the DataIO object */
       DataImpl (const StringView& cache_ext, Prefs& prefs, bool unit_test=false, int cache_megs=10, DataIO * source=new DataIO());
       virtual ~DataImpl ();
       virtual void save_state ();
@@ -90,10 +90,19 @@ namespace pan
       virtual CertStore& get_certstore () { return _certstore; }
       virtual const CertStore& get_certstore () const { return _certstore; }
 
+      virtual Prefs& get_prefs () { return _prefs; }
+      virtual const Prefs& get_prefs () const { return _prefs; }
+
+      virtual Queue* get_queue () { return _queue; }
+      virtual const Queue* get_queue () const { return _queue; }
+
+      virtual void set_queue (Queue* q) { _queue = q; }
+
     private:
       ArticleCache _cache;
       EncodeCache _encode_cache;
       CertStore _certstore;
+      Queue* _queue;
 
     public:
 #ifdef HAVE_GKR
@@ -157,6 +166,9 @@ namespace pan
       virtual void set_server_article_expiration_age  (const Quark  & server,
                                                        int            days);
 
+      virtual void set_server_compression_type  (const Quark   & server,
+                                                 const int       setme);
+
       virtual void save_server_info (const Quark& server);
 
     public: // accessors
@@ -175,6 +187,8 @@ namespace pan
 
       virtual bool get_server_trust (const Quark  & servername, int&) const;
 
+      virtual bool get_server_compression_type (const Quark  & servername, CompressionType&) const;
+
       virtual bool get_server_addr (const Quark   & server,
                                     std::string   & setme_host,
                                     int           & setme_port) const;
@@ -554,6 +568,8 @@ namespace pan
 
       virtual void rescore_articles (const Quark& group, const quarks_t mids);
 
+      virtual void rescore_group_articles (const Quark& group);
+
       virtual void rescore ();
 
     private:
@@ -631,7 +647,8 @@ namespace pan
                                          const StringView     & references,
                                          const unsigned long    byte_count,
                                          const unsigned long    line_count,
-                                         const StringView     & xref);
+                                         const StringView     & xref,
+                                         const bool             is_virtual=false);
 
       /** useful for xover unit testing */
       virtual void xover_flush   (const Quark           & group);
@@ -668,18 +685,18 @@ namespace pan
             RulesFilter   _rules_filter;
 
     private:
-      guint newsrc_autosave_id;
+      mutable guint newsrc_autosave_id;
       guint newsrc_autosave_timeout;
     public:
-      bool in_newsrc_cb;
       void set_newsrc_autosave_timeout(guint seconds)
         {newsrc_autosave_timeout = seconds;}
       void save_newsrc_files()
-      {
-        save_newsrc_files(*_data_io);
+      { // Called from  rc_as_cb(...).
+        // The newsrc_autosave_id is now (soon) invalid since the timeout will be
+        // cancelled when our caller returns FALSE. So forget about it already.
         newsrc_autosave_id = 0;
+        save_newsrc_files(*_data_io);
       }
-
   };
 }
 
