@@ -80,6 +80,12 @@ namespace
     g_free (filename);
     return retval;
   }
+
+  std::string get_download_stats_filename ()
+  {
+    return get_pan_home_file ("downloads.stats");
+  }
+
 }
 
 std::string
@@ -150,6 +156,12 @@ DataIO :: read_group_permissions () const
    return read_file (get_group_permissions_filename ());
 }
 
+LineReader*
+DataIO :: read_download_stats () const
+{
+   return read_file (get_download_stats_filename ());
+}
+
 LineReader*
 DataIO :: read_group_xovers () const
 {
@@ -202,14 +214,21 @@ namespace
 
     const std::string tmpfile (filename + ".tmp");
     if (ok) {
-//      ::remove (filename.c_str()); not needed
-      if (rename (tmpfile.c_str(), filename.c_str()))
-        std::cerr << LINE_ID << " ERROR renaming from [" << tmpfile << "] to [" << filename << "]: " << g_strerror(errno) << '\n';
-      if (chmod (filename.c_str(), 0600))
-        std::cerr << LINE_ID << " ERROR chmodding [" << filename << "]: " << g_strerror(errno) << '\n';
+#if defined(G_OS_WIN32)
+      ::remove (filename.c_str());
+#endif
+      int ret = 0;
+      if ((ret = rename (tmpfile.c_str(), filename.c_str())))
+      {
+        std::cerr << LINE_ID << " ERROR renaming from [" << tmpfile << "] to [" << filename << "]: " << g_strerror(errno) <<" : "<<ret<< '\n';
+      } else
+      {
+        if ((ret = chmod (filename.c_str(), 0600)))
+          std::cerr << LINE_ID << " ERROR chmodding [" << filename << "]: " << g_strerror(errno) << " : "<<ret<<'\n';
+      }
+//      std::cerr<<"dbg "<<ret<<"\n";
     } else {
       Log::add_err_va (_("Unable to save \"%s\" %s"), filename.c_str(), file::pan_strerror(my_errno));
-      ::remove (tmpfile.c_str());
     }
   }
 }
@@ -250,6 +269,12 @@ DataIO :: write_group_headers (const Quark& group)
   return write_file (get_group_headers_filename (group));
 }
 
+std::ostream*
+DataIO :: write_download_stats ()
+{
+   return write_file (get_download_stats_filename ());
+}
+
 std::ostream*
 DataIO :: write_file (const StringView& filename)
 {
