@@ -232,20 +232,25 @@ DataImpl :: xover_add (const Quark         & server,
                        const StringView    & references_in,
                        const unsigned long   byte_count,
                        const unsigned long   line_count,
-                       const StringView    & xref)
+                       const StringView    & xref,
+                       const bool            is_virtual)
 {
+  if (is_virtual)
+    ref_group(group);
+
   GroupHeaders * h (get_group_headers (group));
-  if (!h) {
+  if (!h && !is_virtual) {
     Log::add_err_va (_("Error reading from %s: unknown group \"%s\""),
                      get_server_address(server).c_str(),
                      group.c_str());
     return 0;
   }
 
+
 //  std::cerr<<"xover add : "<<subject<<" "<<author<<" "<<message_id<<" lines "<<line_count<<" bytes "<<byte_count<<std::endl;
 
   const Article* new_article (0);
-  h->_dirty = true;
+
   XOverEntry& workarea (xover_get_workarea (group));
   const std::string references (
     GNKSA :: remove_broken_message_ids_from_references (references_in));
@@ -254,6 +259,8 @@ DataImpl :: xover_add (const Quark         & server,
   **** Multipart Handling
   ***/
 
+  h->_dirty = true;
+
   int part_index, part_count;
   std::string multipart_subject;
   find_parts (subject, group, line_count, part_index, part_count, multipart_subject);
@@ -278,6 +285,7 @@ DataImpl :: xover_add (const Quark         & server,
     }
   }
 
+
   if (art_mid.empty())
   {
     art_mid = message_id;
@@ -322,5 +330,8 @@ DataImpl :: xover_add (const Quark         & server,
   if ((time(0) - workarea._last_flush_time) >= 10)
     xover_flush (group);
 
+  if (is_virtual)
+      unref_group(group);
+
   return new_article;
 }
