@@ -123,6 +123,13 @@ namespace pan
       void copy_url ();
 
       GtkWidget* create_attachments_toolbar(GtkWidget*);
+
+    private:
+#ifdef HAVE_WEBKIT
+      void set_html_text (const char* text);
+      GtkWidget* _web_view;
+#endif
+    private:
       void add_attachment_to_toolbar (const char* fn);
       void clear_attachments();
       GtkWidget* new_attachment (const char* filename);
