@@ -59,6 +59,14 @@ namespace
   };
 }
 
+namespace
+{
+  // default color theme's Colors
+  const PanColors& colors (PanColors::get());
+  const char* def_color_str (colors.def_bg.c_str());
+  const char* def_color_fg_str (colors.def_fg.c_str());
+}
+
 const Article*
 HeaderPane :: get_article (GtkTreeModel* model, GtkTreeIter* iter)
 {
@@ -226,20 +234,25 @@ HeaderPane :: render_score (GtkTreeViewColumn * ,
   const Prefs& prefs (self->_prefs);
   std::string bg, fg;
   if (score >= 9999) {
-    fg = prefs.get_color_str ("score-color-watched-fg", "black");
+    fg = prefs.get_color_str ("score-color-watched-fg", def_color_fg_str);
     bg = prefs.get_color_str ("score-color-watched-bg", TANGO_CHAMELEON_LIGHT);
   } else if (score >= 5000) {
-    fg = prefs.get_color_str ("score-color-high-fg", "black");
+    fg = prefs.get_color_str ("score-color-high-fg", def_color_fg_str);
     bg = prefs.get_color_str ("score-color-high-bg", TANGO_BUTTER_LIGHT);
   } else if (score >= 1) {
-    fg = prefs.get_color_str ("score-color-medium-fg", "black");
+    fg = prefs.get_color_str ("score-color-medium-fg", def_color_fg_str);
     bg = prefs.get_color_str ("score-color-medium-bg", TANGO_SKY_BLUE_LIGHT);
   } else if (score <= -9999) {
     fg = prefs.get_color_str ("score-color-ignored-fg", TANGO_ALUMINUM_4);
-    bg = prefs.get_color_str ("score-color-ignored-bg", "black");
+    bg = prefs.get_color_str ("score-color-ignored-bg", def_color_str);
   } else if (score <= -1) {
     fg = prefs.get_color_str ("score-color-low-fg", TANGO_ALUMINUM_2);
-    bg = prefs.get_color_str ("score-color-low-bg", "black");
+    bg = prefs.get_color_str ("score-color-low-bg", def_color_str);
+  }
+  else if (score == 0)
+  {
+    fg = self->_fg;
+    bg = self->_bg;
   }
 
   g_object_set (renderer, "text", buf,
@@ -262,22 +275,71 @@ HeaderPane :: render_author (GtkTreeViewColumn * ,
   const Article * a (self->get_article (model, iter));
 
   char* ret = __g_mime_iconv_strdup(conv, a->author.c_str());
-  if (ret) g_object_set (renderer, "text", ret, NULL);
+  if (ret) g_object_set (renderer, "text", ret,
+                         "background", self->_bg.c_str(),
+                         "foreground", self->_fg.c_str(),
+                         NULL);
   g_free(ret);
 }
 
+void
+HeaderPane :: render_lines (GtkTreeViewColumn * ,
+                            GtkCellRenderer   * renderer,
+                            GtkTreeModel      * model,
+                            GtkTreeIter       * iter,
+                            gpointer            user_data)
+{
+
+  const HeaderPane * self (static_cast<HeaderPane*>(user_data));
+
+  unsigned long lines(0ul);
+  std::stringstream str;
+
+  gtk_tree_model_get (model, iter, COL_LINES, &lines, -1);
+  str << lines;
+
+  g_object_set (renderer, "text", str.str().c_str(),
+                "background", self->_bg.c_str(),
+                "foreground", self->_fg.c_str(),
+                NULL);
+}
+
 void
 HeaderPane :: render_bytes (GtkTreeViewColumn * ,
                             GtkCellRenderer   * renderer,
                             GtkTreeModel      * model,
                             GtkTreeIter       * iter,
-                            gpointer            )
+                            gpointer            userdata)
 {
+  const HeaderPane * self (static_cast<HeaderPane*>(userdata));
+
   unsigned long bytes (0);
   gtk_tree_model_get (model, iter, COL_BYTES, &bytes, -1);
-  g_object_set (renderer, "text", pan::render_bytes(bytes), NULL);
+  g_object_set (renderer,
+                "text", pan::render_bytes(bytes),
+                "background", self->_bg.c_str(),
+                "foreground", self->_fg.c_str(),
+                NULL);
 }
 
+void
+HeaderPane :: render_date  (GtkTreeViewColumn * ,
+                            GtkCellRenderer   * renderer,
+                            GtkTreeModel      * model,
+                            GtkTreeIter       * iter,
+                            gpointer            userdata)
+{
+  const HeaderPane * self (static_cast<HeaderPane*>(userdata));
+
+  gchar* date (0);
+  gtk_tree_model_get (model, iter, COL_DATE_STR, &date, -1);
+  g_object_set (renderer,
+                "text", date,
+                "background", self->_bg.c_str(),
+                "foreground", self->_fg.c_str(),
+                NULL);
+  g_free (date);
+}
 
 struct HeaderPane::CountUnread: public PanTreeStore::WalkFunctor
 {
@@ -346,8 +408,8 @@ HeaderPane :: render_subject (GtkTreeViewColumn * ,
   g_object_set (renderer,
     "text", res.c_str(),
     "weight", (bold ? PANGO_WEIGHT_BOLD : PANGO_WEIGHT_NORMAL),
-    "foreground", unread ? (def_fg.empty() ? NULL : def_fg.c_str()) : NULL,
-    "background", unread ? (def_bg.empty() ? NULL : def_bg.c_str()) : NULL, NULL);
+    "foreground", unread ? (def_fg.empty() ? self->_fg.c_str() : def_fg.c_str()) : self->_fg.c_str(),
+    "background", unread ? (def_bg.empty() ? self->_bg.c_str() : def_bg.c_str()) : self->_bg.c_str(), NULL);
 
 }
 
@@ -373,11 +435,6 @@ HeaderPane :: create_row (const EvolutionDateMaker & e,
   return row;
 }
 
-namespace
-{
-  typedef std::vector<const Article*> article_v;
-}
-
 void
 HeaderPane ::  add_children_to_model (PanTreeStore               * store,
                                       PanTreeStore::Row          * parent_row,
@@ -689,6 +746,26 @@ namespace
   };
 }
 
+void
+HeaderPane :: collapse_selected()
+{
+  {
+  // get a list of paths
+  GtkTreeModel * model (0);
+  GtkTreeView * view (GTK_TREE_VIEW (_tree_view));
+  GtkTreeSelection * selection (gtk_tree_view_get_selection (view));
+  GList * list (gtk_tree_selection_get_selected_rows (selection, &model));
+  if (list)
+  {
+    GtkTreePath * path (static_cast<GtkTreePath*>(list->data));
+    gtk_tree_view_collapse_row (view, path);
+//    gtk_tree_view_expand_to_path (view, path);
+  }
+  g_list_foreach (list, (GFunc)gtk_tree_path_free, NULL);
+  g_list_free (list);
+}
+}
+
 void
 HeaderPane :: select_message_id (const Quark& mid, bool do_scroll)
 {
@@ -1083,8 +1160,25 @@ namespace
     return false;
 
   }
+  static gboolean left_pressed (gpointer data)
+  {
+    HeaderPane * self (static_cast<HeaderPane*>(data));
+    // TODO move this into headerpane
+    self->_gui.do_collapse_thread ();
+    return false;
+
+  }
+  static gboolean right_pressed (gpointer data)
+  {
+    HeaderPane * self (static_cast<HeaderPane*>(data));
+    // TODO move this into headerpane
+    self->_gui.do_expand_thread ();
+    return false;
+
+  }
 }
 
+// TODO just pass TRUE and let actions.cc handle that!
 gboolean
 HeaderPane :: on_keyboard_button_pressed ( GtkWidget *widget, GdkEventKey *event, gpointer data)
 {
@@ -1095,6 +1189,16 @@ HeaderPane :: on_keyboard_button_pressed ( GtkWidget *widget, GdkEventKey *event
       g_idle_add(return_pressed_download_all, data);
       return TRUE;
     }
+    if (event->keyval == GDK_KEY_Left)
+    {
+      g_idle_add(left_pressed, data);
+      return TRUE;
+    }
+    if (event->keyval == GDK_KEY_Right)
+    {
+      g_idle_add(right_pressed, data);
+      return TRUE;
+    }
   }
 
   return FALSE;
@@ -1250,25 +1354,29 @@ HeaderPane :: rebuild_rules (bool enable)
 
   RulesInfo &r (_rules);
   r.set_type_aggregate_and ();
-  RulesInfo tmp;
+  RulesInfo *tmp;
 
   std::pair<int,int> res;
 
   res = get_int_from_rules_str(_prefs.get_string("rules-delete-value", "never"));
-  tmp.set_type_delete_b (res.first, res.second);
+  tmp = new RulesInfo;
+  tmp->set_type_delete_b (res.first, res.second);
   r._aggregates.push_back (tmp);
 
   res = get_int_from_rules_str(_prefs.get_string("rules-mark-read-value", "never"));
-  tmp.set_type_mark_read_b (res.first, res.second);
+  tmp = new RulesInfo;
+  tmp->set_type_mark_read_b (res.first, res.second);
   r._aggregates.push_back (tmp);
 
   res = get_int_from_rules_str(_prefs.get_string("rules-autocache-value", "never"));
-  tmp.set_type_autocache_b (res.first, res.second);
+  tmp = new RulesInfo;
+  tmp->set_type_autocache_b (res.first, res.second);
   r._aggregates.push_back (tmp);
 
   res = get_int_from_rules_str(_prefs.get_string("rules-auto-dl-value", "never"));
-  tmp.set_type_dl_b (res.first, res.second);
-   r._aggregates.push_back (tmp);
+  tmp = new RulesInfo;
+  tmp->set_type_dl_b (res.first, res.second);
+  r._aggregates.push_back (tmp);
 
 }
 
@@ -1287,56 +1395,62 @@ HeaderPane :: rebuild_filter (const std::string& text, int mode)
   f.set_type_aggregate_and ();
 
   // entry field filter...
-  FilterInfo entry_filter;
   if (!text.empty())
   {
+    FilterInfo *entry_filter = new FilterInfo;
     if (mode == SUBJECT)
-      entry_filter.set_type_text ("Subject", d);
+      entry_filter->set_type_text ("Subject", d);
     else if (mode == AUTHOR)
-      entry_filter.set_type_text ("From", d);
+      entry_filter->set_type_text ("From", d);
     else if (mode == MESSAGE_ID)
-      entry_filter.set_type_text ("Message-ID", d);
+      entry_filter->set_type_text ("Message-ID", d);
     else if (mode == SUBJECT_OR_AUTHOR) {
-      FilterInfo f1, f2;
-      entry_filter.set_type_aggregate_or ();
-      f1.set_type_text ("Subject", d);
-      f2.set_type_text ("From", d);
-      entry_filter._aggregates.push_back (f1);
-      entry_filter._aggregates.push_back (f2);
+      FilterInfo *f1 = new FilterInfo, *f2 = new FilterInfo;
+      entry_filter->set_type_aggregate_or ();
+      f1->set_type_text ("Subject", d);
+      f2->set_type_text ("From", d);
+      entry_filter->_aggregates.push_back (f1);
+      entry_filter->_aggregates.push_back (f2);
     } else if (mode == SUBJECT_OR_AUTHOR_REGEX) {
-      FilterInfo f1, f2;
-      entry_filter.set_type_aggregate_or ();
+      FilterInfo *f1 = new FilterInfo, *f2 = new FilterInfo;
+      entry_filter->set_type_aggregate_or ();
       d.type = TextMatch::REGEX;
-      f1.set_type_text ("Subject", d);
-      f2.set_type_text ("From", d);
-      entry_filter._aggregates.push_back (f1);
-      entry_filter._aggregates.push_back (f2);
+      f1->set_type_text ("Subject", d);
+      f2->set_type_text ("From", d);
+      entry_filter->_aggregates.push_back (f1);
+      entry_filter->_aggregates.push_back (f2);
     }
     f._aggregates.push_back (entry_filter);
   }
 
+  if (_action_manager.is_action_active("match-only-read-articles")) {
+//std::cerr << LINE_ID << " AND is read" << std::endl;
+    FilterInfo *tmp = new FilterInfo;
+    tmp->set_type_is_read ();
+    f._aggregates.push_back (tmp);
+  }
   if (_action_manager.is_action_active("match-only-unread-articles")) {
 //std::cerr << LINE_ID << " AND is unread" << std::endl;
-    FilterInfo tmp;
-    tmp.set_type_is_unread ();
+    FilterInfo *tmp = new FilterInfo;
+    tmp->set_type_is_unread ();
     f._aggregates.push_back (tmp);
   }
   if (_action_manager.is_action_active("match-only-cached-articles")) {
 //std::cerr << LINE_ID << " AND is cached" << std::endl;
-    FilterInfo tmp;
-    tmp.set_type_cached ();
+    FilterInfo *tmp = new FilterInfo;
+    tmp->set_type_cached ();
     f._aggregates.push_back (tmp);
   }
   if (_action_manager.is_action_active("match-only-binary-articles")) {
 //std::cerr << LINE_ID << " AND has an attachment" << std::endl;
-    FilterInfo tmp;
-    tmp.set_type_binary ();
+    FilterInfo *tmp = new FilterInfo;
+    tmp->set_type_binary ();
     f._aggregates.push_back (tmp);
   }
   if (_action_manager.is_action_active("match-only-my-articles")) {
 //std::cerr << LINE_ID << " AND was posted by me" << std::endl;
-    FilterInfo tmp;
-    tmp.set_type_posted_by_me ();
+    FilterInfo *tmp = new FilterInfo;
+    tmp->set_type_posted_by_me ();
     f._aggregates.push_back (tmp);
   }
 
@@ -1365,7 +1479,7 @@ HeaderPane :: rebuild_filter (const std::string& text, int mode)
 
 //for (size_t i=0; i<ranges.size(); ++i) std::cerr << LINE_ID << " range [" << ranges[i].first << "..." << ranges[i].second << "]" << std::endl;
 
-  std::deque<FilterInfo> filters;
+  std::deque<FilterInfo *> filters;
   for (size_t i=0; i<ranges.size(); ++i) {
     const range_t& range (ranges[i]);
     const bool low_bound (range.first == INT_MIN);
@@ -1373,22 +1487,23 @@ HeaderPane :: rebuild_filter (const std::string& text, int mode)
     if (low_bound && hi_bound) {
       // everything matches -- do nothing
     } else if (hi_bound) {
-      FilterInfo tmp;
-      tmp.set_type_score_ge (range.first);
+      FilterInfo *tmp = new FilterInfo;
+      tmp->set_type_score_ge (range.first);
 //std::cerr << LINE_ID << " AND has a score >= " << range.first << std::endl;
       filters.push_back (tmp);
     } else if (low_bound) {
-      FilterInfo tmp;
-      tmp.set_type_score_le (range.second);
+      FilterInfo *tmp = new FilterInfo;
+      tmp->set_type_score_le (range.second);
 //std::cerr << LINE_ID << " AND has a score <= " << range.second << std::endl;
       filters.push_back (tmp);
     } else  { // not bound on either side; need an aggregate
-      FilterInfo s, tmp;
-      s.set_type_aggregate_and ();
-      tmp.set_type_score_ge (range.first);
-      s._aggregates.push_back (tmp);
-      tmp.set_type_score_le (range.second);
-      s._aggregates.push_back (tmp);
+      FilterInfo *tmp = new FilterInfo;
+      FilterInfo *s = new FilterInfo;
+      s->set_type_aggregate_and ();
+      tmp->set_type_score_ge (range.first);
+      s->_aggregates.push_back (tmp);
+      tmp->set_type_score_le (range.second);
+      s->_aggregates.push_back (tmp);
 //std::cerr << LINE_ID << " AND has a in [" << range.first << "..." << range.second << ']' << std::endl;
       filters.push_back (s);
     }
@@ -1396,9 +1511,9 @@ HeaderPane :: rebuild_filter (const std::string& text, int mode)
   if (filters.size()==1) // can fit in an `and' parent
     f._aggregates.push_back (filters[0]);
   else if (!filters.empty()) { // needs an `or' parent
-    FilterInfo s;
-    s.set_type_aggregate_or ();
-    s._aggregates.swap (filters);
+    FilterInfo *s = new FilterInfo;
+    s->set_type_aggregate_or ();
+    s->_aggregates.swap (filters);
     f._aggregates.push_back (s);
   }
 //std::cerr << LINE_ID << " number of filters: " << f._aggregates.size() << std::endl;
@@ -1684,11 +1799,12 @@ HeaderPane :: build_tree_columns ()
         "xalign", 1.0,
         NULL));
       ellipsize_if_supported (G_OBJECT(r));
-      col = gtk_tree_view_column_new_with_attributes (_("Lines"), r, "text", COL_LINES, NULL);
+      col = gtk_tree_view_column_new_with_attributes (_("Lines"), r, NULL);
       gtk_tree_view_column_set_sizing (col, GTK_TREE_VIEW_COLUMN_FIXED);
       gtk_tree_view_column_set_fixed_width (col, _prefs.get_int (width_key, 60));
       gtk_tree_view_column_set_resizable (col, true);
       gtk_tree_view_column_set_sort_column_id (col, COL_LINES);
+      gtk_tree_view_column_set_cell_data_func (col, r, render_lines, this, 0);
       gtk_tree_view_append_column (tree_view, col);
     }
     else if (name == "bytes")
@@ -1714,11 +1830,12 @@ HeaderPane :: build_tree_columns ()
         "ypad", 0,
         NULL));
       ellipsize_if_supported (G_OBJECT(r));
-      col = gtk_tree_view_column_new_with_attributes (_("Date"), r, "text", COL_DATE_STR, NULL);
+      col = gtk_tree_view_column_new_with_attributes (_("Date"), r, NULL);
       gtk_tree_view_column_set_sizing (col, GTK_TREE_VIEW_COLUMN_FIXED);
       gtk_tree_view_column_set_fixed_width (col, _prefs.get_int (width_key, 120));
       gtk_tree_view_column_set_resizable (col, true);
       gtk_tree_view_column_set_sort_column_id (col, COL_DATE);
+      gtk_tree_view_column_set_cell_data_func (col, r, render_date, this, 0);
       gtk_tree_view_append_column (tree_view, col);
     }
 
@@ -1783,12 +1900,12 @@ HeaderPane :: create_filter_entry ()
   g_signal_connect (entry, "activate", G_CALLBACK(search_entry_activated), this);
   entry_changed_tag = g_signal_connect (entry, "changed", G_CALLBACK(search_entry_changed), this);
 
-      gtk_entry_set_icon_from_stock( GTK_ENTRY( entry ),
-                                   GTK_ENTRY_ICON_PRIMARY,
-                                   GTK_STOCK_FIND);
-   gtk_entry_set_icon_from_stock( GTK_ENTRY( entry ),
-                                  GTK_ENTRY_ICON_SECONDARY,
-                                  GTK_STOCK_CLEAR );
+  gtk_entry_set_icon_from_stock( GTK_ENTRY( entry ),
+                                 GTK_ENTRY_ICON_PRIMARY,
+                                 GTK_STOCK_FIND);
+  gtk_entry_set_icon_from_stock( GTK_ENTRY( entry ),
+                                 GTK_ENTRY_ICON_SECONDARY,
+                                 GTK_STOCK_CLEAR );
 
   bool regex = _prefs.get_flag ("use-regex", false);
   GtkWidget * menu = gtk_menu_new ();
@@ -1881,8 +1998,11 @@ HeaderPane :: HeaderPane (ActionManager       & action_manager,
   _selection_changed_idle_tag (0),
   _cache (cache),
   _gui (gui),
-  _cleared (true)
+  _cleared (true),
+  _fg(prefs.get_color_str_wo_fallback ("text-color-fg")),
+  _bg(prefs.get_color_str_wo_fallback ("text-color-bg"))
 {
+
   // init the icons
   for (guint i=0; i<ICON_QTY; ++i)
     _icons[i].pixbuf = gdk_pixbuf_new_from_inline (-1, _icons[i].pixbuf_txt, FALSE, 0);
@@ -1910,7 +2030,7 @@ HeaderPane :: HeaderPane (ActionManager       & action_manager,
   g_signal_connect (w, "button-release-event", G_CALLBACK(on_button_pressed), this);
   g_signal_connect (w, "button-press-event", G_CALLBACK(on_button_pressed), this);
 
-  /* intercept ENTER for selection of multiple articles */
+  /* intercept ENTER and left/right for article selection */
   g_signal_connect (w, "key-press-event", G_CALLBACK(on_keyboard_button_pressed), this);
 
   g_signal_connect (w, "row-collapsed", G_CALLBACK(row_collapsed_cb), NULL);
@@ -1928,6 +2048,7 @@ HeaderPane :: HeaderPane (ActionManager       & action_manager,
   _root = scroll;
 
   search_activate (this); // calls rebuild_filter
+  _prefs._rules_enabled = prefs.get_flag("enable-rules", true);
   rules(_prefs._rules_enabled);
 
   _data.add_listener (this);
@@ -2363,6 +2484,19 @@ HeaderPane :: on_prefs_string_changed (const StringView& key, const StringView&)
     build_tree_columns ();
 }
 
+void
+HeaderPane :: on_prefs_color_changed  (const StringView& key, const GdkColor&)
+{
+  if (key == "text-color-fg" || key == "text-color-bg")
+  {
+    _fg = _prefs.get_color_str ("text-color-fg", def_color_fg_str).c_str();
+    _bg = _prefs.get_color_str ("text-color-bg", def_color_str).c_str();
+    refresh_font();
+    build_tree_columns();
+  }
+
+}
+
 /***
 ****
 ***/
@@ -2408,6 +2542,7 @@ HeaderPane :: on_cache_added (const Quark& message_id)
 {
   quarks_t q;
   q.insert(message_id);
+  //TODO fixme!!
   _data.rescore_articles ( _group, q );
   rebuild_article_action (message_id);
 
