@@ -35,6 +35,7 @@
 #include <pan/gui/group-prefs.h>
 #include <pan/gui/wait.h>
 #include <pan/gui/gui.h>
+#include <pan/gui/body-pane.h>
 
 namespace pan
 {
@@ -67,6 +68,7 @@ namespace pan
 
   typedef std::vector<const Article*> articles_t;
   typedef std::set<const Article*> articles_set;
+  typedef std::vector<const Article*> article_v;
 
   /**
    * Header Pane in the main window of Pan's GUI.
@@ -95,6 +97,7 @@ namespace pan
       void select_subthreads ();
       void select_similar ();
       void expand_selected ();
+      void collapse_selected();
 
     public:
       void read_next_article ();
@@ -148,7 +151,7 @@ namespace pan
       virtual void on_prefs_flag_changed   (const StringView&, bool);
       virtual void on_prefs_int_changed    (const StringView&, int) { }
       virtual void on_prefs_string_changed (const StringView&, const StringView&);
-      virtual void on_prefs_color_changed  (const StringView&, const GdkColor&) {}
+      virtual void on_prefs_color_changed  (const StringView&, const GdkColor&);
 
     public:
       virtual void on_article_flag_changed (articles_t& a, const Quark& group);
@@ -320,6 +323,10 @@ namespace pan
       Data::ShowType _show_type;
       guint _selection_changed_idle_tag;
 
+      // default text colors, updated on prefs change
+      std::string _fg;
+      std::string _bg;
+
     private:
       void rebuild_filter (const std::string&, int);
       void rebuild_rules (bool enable=false);
@@ -359,6 +366,8 @@ namespace pan
       static RenderFunc render_bytes;
       static RenderFunc render_subject;
       static RenderFunc render_author;
+      static RenderFunc render_lines;
+      static RenderFunc render_date;
 
     private:
       Row* get_row (const Quark& message_id);
@@ -366,6 +375,8 @@ namespace pan
     private:
       static void on_selection_changed (GtkTreeSelection*, gpointer);
       static gboolean on_selection_changed_idle (gpointer);
+      static void sort_column_changed_cb (GtkTreeSortable *sortable,
+                                           gpointer         user_data);
 
     private:
       void find_next_iterator_from (GtkTreeModel            * model,
@@ -379,6 +390,14 @@ namespace pan
                           const TreeIterFunctor  & iterate_func,
                           const ArticleTester    & test_func,
                           RowActionFunctor       & success_func);
+    private:
+
+      bool _cleared;
+
+    public:
+      void clear() { set_group(Quark()); set_cleared(true); }
+      void set_cleared(bool val) { _cleared = val; }
+      bool get_cleared() { return _cleared; }
   };
 }
 
