@@ -866,7 +866,9 @@ namespace
     fg_col = GroupPrefs::color_to_string(def_fg);
     bg_col = GroupPrefs::color_to_string(def_bg);
 
+    g_object_ref_sink (r);
     gtk_widget_destroy (r);
+    g_object_unref (r);
 
     PanColors& c (PanColors::get());
     c.def_fg = fg_col;
@@ -884,7 +886,10 @@ main (int argc, char *argv[])
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 
+#if !GLIB_CHECK_VERSION(2,36,0)
   g_type_init();
+#endif
+
 #if !GLIB_CHECK_VERSION(2,32,0)
   g_thread_init (0);
 #endif
@@ -1129,6 +1134,8 @@ main (int argc, char *argv[])
 #endif
 
 #ifdef HAVE_GKR
+  if (!data.get_servers().empty())
+  {
     // free secure passwords
     foreach(quarks_t, data.get_servers(), it)
     {
@@ -1138,6 +1145,7 @@ main (int argc, char *argv[])
         gnome_keyring_memory_free(s->gkr_pw);
       }
     }
+  }
 #endif
   }
 
