@@ -50,6 +50,7 @@ const char * fallback_ui_file =
 "        <menuitem action='show-matching-subthreads' />\n"
 "        <separator />\n"
 "        <menuitem action='match-only-unread-articles' />\n"
+"        <menuitem action='match-only-read-articles' />\n"
 "        <menuitem action='match-only-cached-articles' />\n"
 "        <menuitem action='match-only-binary-articles' />\n"
 "        <menuitem action='match-only-my-articles' />\n"
@@ -178,6 +179,7 @@ const char * fallback_ui_file =
 "    <placeholder name='header-pane-filter' />\n"
 "    <separator />\n"
 "    <toolitem action='match-only-unread-articles' />\n"
+"    <toolitem action='match-only-read-articles' />\n"
 "    <toolitem action='match-only-cached-articles' />\n"
 "    <toolitem action='match-only-binary-articles' />\n"
 "    <toolitem action='match-only-my-articles' />\n"
