@@ -29,8 +29,6 @@
 #include <pan/data/encode-cache.h>
 #include "group-prefs.h"
 
-#include <pan/usenet-utils/MersenneTwister.h>
-
 namespace pan
 {
   class Profiles;
@@ -104,6 +102,9 @@ namespace pan
       void done_sending_message (GMimeMessage*, bool);
       void maybe_mail_message (GMimeMessage*);
       bool maybe_post_message (GMimeMessage*);
+      enum Mode { DRAFTING, POSTING, UPLOADING, VIRTUAL};
+      bool save_message_in_local_folder(const Mode& mode, const std::string& folder);
+      std::string generate_message_id (const Profile& p);
 
     private:
       void update_widgetry ();
@@ -157,12 +158,13 @@ namespace pan
 
       GMimeContentEncoding _enc;
 
+      guint _child_id;
+
       /* binpost */
       bool _file_queue_empty;
       TaskUpload* _upload_ptr;
       int _total_parts;
       std::string _save_file;
-      MTRand rng;
       int _uploads;
 
     public:
@@ -178,7 +180,6 @@ namespace pan
       void add_actions (GtkWidget* box);
       void apply_profile_to_body ();
       void apply_profile_to_headers ();
-      enum Mode { DRAFTING, POSTING, UPLOADING};
       GMimeMessage * new_message_from_ui (Mode mode, bool copy_body=true);
       bool check_message (const Quark& server, GMimeMessage*, bool binpost=false);
       bool check_charset ();
@@ -202,6 +203,7 @@ namespace pan
     private:
       std::string utf8ize (const StringView&) const;
       std::string get_body () const;
+      int count_lines();
       gulong body_view_realized_handler;
       static void body_view_realized_cb (GtkWidget*, gpointer);
       GtkWidget* create_body_widget (GtkTextBuffer*&, GtkWidget*&, const pan::Prefs&);
@@ -248,8 +250,6 @@ namespace pan
       std::ofstream _out;
       static void message_id_toggled_cb (GtkToggleButton * tb, gpointer prefs_gpointer);
 
-      void generate_unique_id (StringView& mid, int cnt, std::string& s);
-
       int get_total_parts(const char* file);
 
     private:
