@@ -36,6 +36,8 @@ extern "C" {
 #include "e-charset-dialog.h"
 #include "actions-extern.h"
 
+#include <algorithm>
+
 using namespace pan;
 
 namespace pan
@@ -83,6 +85,7 @@ namespace pan
       static_cast<CallBackData*>(user_data)->dialog->update_hotkey(user_data);
     }
     gtk_widget_destroy(dialog);
+    delete static_cast<CallBackData*>(user_data);
   }
 }
 
@@ -268,7 +271,6 @@ namespace pan
 
   }
 
-
   void save_accels()
   {
 
@@ -291,6 +293,8 @@ namespace pan
   {
     PrefsDialog* pd(static_cast<PrefsDialog*>(castme));
     save_accels();
+    pd->prefs().set_int("prefs-last-selected-page",
+                        gtk_notebook_get_current_page(GTK_NOTEBOOK(pd->notebook())));
     pd->prefs().remove_listener(pd);
     delete pd;
   }
@@ -339,7 +343,7 @@ namespace pan
   {
     GtkWidget * t = gtk_entry_new();
     g_object_set_data_full (G_OBJECT(t), PREFS_KEY, g_strdup(key), g_free);
-    gtk_entry_set_text (GTK_ENTRY(t), prefs.get_string (key, fallback).c_str());
+    gtk_entry_set_text (GTK_ENTRY(t), prefs.get_string (key, fallback).str);
     g_signal_connect (t, "changed", G_CALLBACK(entry_changed_cb), &prefs);
     return t;
   }
@@ -381,7 +385,7 @@ namespace pan
 
   GtkWidget* new_spin_button (const char *key, int low, int high, Prefs &prefs)
   {
-    guint tm = prefs.get_int(key, 5 );
+    guint tm = prefs.get_int(key, low );
     GtkAdjustment *adj = (GtkAdjustment*) gtk_adjustment_new(tm, low, high, 1.0, 1.0, 0.0);
     GtkWidget *w = gtk_spin_button_new( adj, 1.0, 0);
     g_object_set_data_full(G_OBJECT(w), PREFS_KEY, g_strdup(key), g_free);
@@ -408,7 +412,7 @@ namespace pan
     const bool icons = "icons" == what;
     const bool both  = "both"  == what;
 
-    GtkWidget* hbox = gtk_hbox_new(false, 2);
+    GtkWidget* hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
     GdkPixbuf * pixbuf = gdk_pixbuf_new_from_inline (-1, line, false, 0);
     GtkWidget * image = gtk_image_new_from_pixbuf (pixbuf);
     g_object_unref (pixbuf);
@@ -419,6 +423,13 @@ namespace pan
     return hbox;
   }
 
+  std::string remove_underscores (std::string& src)
+  {
+    std::string res (src);
+    res.erase(std::remove(res.begin(), res.end(), '_'), res.end());
+    return res;
+  }
+
   void fill_pref_hotkeys(GtkWidget* t, int& row, Prefs& prefs, gpointer dialog_ptr)
   {
 
@@ -441,7 +452,7 @@ namespace pan
       data->value = stripped;
 
       w = new_hotkey_entry(keyval, it->first.c_str(), data);
-      std::string label = action_trans[stripped];
+      std::string label = remove_underscores(action_trans[stripped]);
       l = gtk_label_new(label.c_str());
       HIG :: workarea_add_row (t, &row, w, l);
     }
@@ -490,6 +501,21 @@ namespace pan
     g_free (val);
   }
 
+  GtkWidget* html_previewer_new (Prefs& prefs)
+  {
+    const char * key = "html-previewer";
+//    const std::string editor = prefs.get_string (key, "mutt");
+//    editors.insert (editor);
+    GtkWidget * c = gtk_combo_box_text_new_with_entry ();
+    g_object_set_data_full (G_OBJECT(c), PREFS_KEY, g_strdup(key), g_free);
+//    foreach_const (std::set<std::string>, editors, it)
+//      gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT(c), it->c_str());
+//    gtk_combo_box_set_active (GTK_COMBO_BOX(c),
+//                              (int)std::distance (editors.begin(), editors.find(editor)));
+    g_signal_connect (c, "changed", G_CALLBACK(set_prefs_string_from_combo_box_entry), &prefs);
+    return c;
+  }
+
   GtkWidget* editor_new (Prefs& prefs)
   {
     std::set<std::string> editors;
@@ -605,7 +631,7 @@ namespace pan
 
     // tie them together...
     g_signal_connect (c, "changed", G_CALLBACK(maybe_make_widget_visible), e);
-    GtkWidget * h = gtk_hbox_new (false, PAD);
+    GtkWidget * h = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, PAD);
     gtk_box_pack_start (GTK_BOX(h), c, true, true, 0);
     gtk_box_pack_start (GTK_BOX(h), e, true, true, 0);
 
@@ -714,7 +740,6 @@ PrefsDialog :: on_prefs_string_changed (const StringView& key, const StringView&
     _prefs.save();
     update_default_charset_label(value);
   }
-
 }
 
 void
@@ -722,10 +747,7 @@ PrefsDialog :: on_prefs_flag_changed (const StringView& key, bool value)
 {
 
   if (key == "allow-multiple-instances")
-  {
     _prefs.save();
-  }
-
 }
 
 namespace
@@ -877,9 +899,9 @@ namespace
     GtkWidget * f = gtk_frame_new (NULL);
     gtk_frame_set_shadow_type (GTK_FRAME(f), GTK_SHADOW_IN);
     gtk_container_add (GTK_CONTAINER(f), view);
-    GtkWidget * hbox = gtk_hbox_new (false, PAD);
+    GtkWidget * hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, PAD);
     gtk_box_pack_start (GTK_BOX(hbox), f, true, true, 0);
-    GtkWidget * vbox = gtk_vbox_new (false, PAD);
+    GtkWidget * vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, PAD);
     GtkWidget * up = gtk_button_new_from_stock (GTK_STOCK_GO_UP);
     gtk_box_pack_start (GTK_BOX(vbox), up, false, false, 0);
     GtkWidget * down = gtk_button_new_from_stock (GTK_STOCK_GO_DOWN);
@@ -913,7 +935,7 @@ PrefsDialog :: PrefsDialog (Prefs& prefs, GtkWindow* parent):
   g_signal_connect (dialog, "response", G_CALLBACK(response_cb), this);
   g_signal_connect_swapped (dialog, "destroy", G_CALLBACK(delete_prefs_dialog), this);
 
-  GtkWidget * notebook = gtk_notebook_new ();
+  GtkWidget* notebook = _notebook = gtk_notebook_new ();
   gtk_notebook_set_scrollable (GTK_NOTEBOOK(notebook), true);
 
   // Behavior
@@ -943,7 +965,9 @@ PrefsDialog :: PrefsDialog (Prefs& prefs, GtkWindow* parent):
     HIG::workarea_add_section_divider (t, &row);
 
     HIG :: workarea_add_section_title (t, &row, _("Articles"));
-    HIG :: workarea_add_section_spacer (t, row, 5);
+    HIG :: workarea_add_section_spacer (t, row, 6);
+    w = new_check_button (_("Mark downloaded articles read"), "mark-downloaded-articles-read", false, prefs);
+    HIG :: workarea_add_wide_control (t, &row, w);
     w = new_check_button (_("Space selects next article rather than next unread"), "space-selects-next-article", true, prefs);
     HIG :: workarea_add_wide_control (t, &row, w);
     w = new_check_button (_("Expand threads upon selection"), "expand-selected-articles", false, prefs);
@@ -976,6 +1000,19 @@ PrefsDialog :: PrefsDialog (Prefs& prefs, GtkWindow* parent):
   HIG :: workarea_finish (t, &row);
   gtk_notebook_append_page (GTK_NOTEBOOK(notebook), t, new_label_with_icon(_("_Behavior"), _("Behavior"), icon_prefs_behavior, prefs));
 
+  // pane options
+  row = 0;
+  t = HIG :: workarea_create ();
+    HIG::workarea_add_section_spacer (t, row, 1);
+    HIG :: workarea_add_section_title (t, &row, _("Task Pane"));
+    w = new_check_button (_("Show task pane popups"), "show-taskpane-popups", true, prefs);
+    HIG :: workarea_add_wide_control (t, &row, w);
+    w = new_check_button (_("Show Download Meter"), "dl-meter-show", true, prefs);
+    HIG :: workarea_add_wide_control (t, &row, w);
+    HIG::workarea_add_section_divider (t, &row);
+  HIG :: workarea_finish (t, &row);
+  gtk_notebook_append_page (GTK_NOTEBOOK(notebook), t, new_label_with_icon(_("_Panes"), _("Panes"), icon_prefs_panes, prefs));
+
   //charset
   row = 0;
   t = HIG :: workarea_create ();
@@ -991,7 +1028,7 @@ PrefsDialog :: PrefsDialog (Prefs& prefs, GtkWindow* parent):
     // systray and notify popup
     HIG :: workarea_add_section_title (t, &row, _("System Tray Behavior"));
     HIG :: workarea_add_section_spacer (t, row, 3);
-    w = new_check_button (_("Hide to system tray"), "status-icon", false, prefs);
+    w = new_check_button (_("Minimize to tray"), "status-icon", false, prefs);
     HIG :: workarea_add_wide_control (t, &row, w);
     w = new_check_button (_("Start Pan minimized"), "start-minimized", false, prefs);
     HIG :: workarea_add_wide_control (t, &row, w);
@@ -1022,6 +1059,12 @@ PrefsDialog :: PrefsDialog (Prefs& prefs, GtkWindow* parent):
     gtk_label_set_mnemonic_widget(GTK_LABEL(l), w);
     HIG::workarea_add_row (t, &row, l, w);
 
+    // Gnome Keyring Option
+    HIG :: workarea_add_section_spacer (t, row, 2);
+    HIG :: workarea_add_section_title (t, &row, _("GNOME Keyring"));
+    w = new_check_button (_("Store passwords in GNOME Keyring"), "use-gnome-keyring", false, prefs);
+    HIG :: workarea_add_wide_control (t, &row, w);
+
   HIG :: workarea_finish (t, &row);
   gtk_notebook_append_page (GTK_NOTEBOOK(notebook), t, new_label_with_icon(_("_Miscellaneous"), _("Miscellaneous"), icon_prefs_extras, prefs));
 
@@ -1031,7 +1074,7 @@ PrefsDialog :: PrefsDialog (Prefs& prefs, GtkWindow* parent):
   HIG :: workarea_add_section_title (t, &row, _("Pane Layout"));
     std::string cur = _prefs.get_string ("pane-layout", "stacked-right");
     HIG :: workarea_add_section_spacer (t, row, 1);
-    h = gtk_hbox_new (false, PAD);
+    h = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, PAD);
     w = new_layout_radio (0, icon_layout_1, "stacked-top", cur, prefs);
     gtk_box_pack_start (GTK_BOX(h), w, false, false, 0);
     w = new_layout_radio (w, icon_layout_2, "stacked-bottom", cur, prefs);
@@ -1076,16 +1119,39 @@ PrefsDialog :: PrefsDialog (Prefs& prefs, GtkWindow* parent):
   row = 0;
   t = HIG :: workarea_create ();
 
-    gtk_widget_set_tooltip_text (t, _("This menu lets you configure Pan to take certain actions on your behalf automatically, based on an article's score."));
+    gtk_widget_set_tooltip_text (t, _("This menu lets you configure Pan to take certain actions on your behalf automatically, "
+                                      "based on an article's score."));
 
+    int i(0);
+    GtkWidget** action_combo = new GtkWidget*[2];
+    char* tmp = _("Mark affected articles read");
+    action_combo[i++] = new_check_button (tmp, "rules-autocache-mark-read", false, prefs);
+    action_combo[i++] = new_check_button (tmp, "rules-auto-dl-mark-read", false, prefs);
+
+    i=0;
     w = score_handler_new (prefs, "rules-delete-value", "never", b);
-    HIG :: workarea_add_row (t, &row, _("_Delete articles scoring at: "), w);
+    h = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, PAD);
+    gtk_box_pack_start (GTK_BOX(h), w, false, false, 0);
+    gtk_box_pack_start (GTK_BOX(h), gtk_label_new(NULL), false, false, 0);
+    HIG :: workarea_add_row (t, &row, _("_Delete articles scoring at: "), h);
+
     w = score_handler_new (prefs, "rules-mark-read-value", "never", b);
-    HIG :: workarea_add_row (t, &row, _("Mark articles as _read scoring at: "), w);
+    h = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, PAD);
+    gtk_box_pack_start (GTK_BOX(h), w, false, false, 0);
+    gtk_box_pack_start (GTK_BOX(h), gtk_label_new(NULL), false, false, 0);
+    HIG :: workarea_add_row (t, &row, _("Mark articles read scoring at: "), h);
+
     w = score_handler_new (prefs, "rules-autocache-value", "never", b);
-    HIG :: workarea_add_row (t, &row, _("_Cache articles scoring at: "), w);
+    h = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, PAD);
+    gtk_box_pack_start (GTK_BOX(h), w, false, false, 0);
+    gtk_box_pack_start (GTK_BOX(h), action_combo[i++], false, false, 0);
+    HIG :: workarea_add_row (t, &row, _("_Cache articles scoring at: "), h);
+
     w = score_handler_new (prefs, "rules-auto-dl-value", "never", b);
-    HIG :: workarea_add_row (t, &row, _("Download _attachments of articles scoring at: "), w);
+    h = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, PAD);
+    gtk_box_pack_start (GTK_BOX(h), w, false, false, 0);
+    gtk_box_pack_start (GTK_BOX(h), action_combo[i++], false, false, 0);
+    HIG :: workarea_add_row (t, &row, _("Download attachments of articles scoring at: "), h);
 
   HIG :: workarea_finish (t, &row);
   gtk_notebook_append_page (GTK_NOTEBOOK(notebook), t, new_label_with_icon(_("_Actions"), _("Actions"), icon_prefs_actions, prefs));
@@ -1116,58 +1182,106 @@ PrefsDialog :: PrefsDialog (Prefs& prefs, GtkWindow* parent):
   HIG :: workarea_finish (t, &row);
   gtk_notebook_append_page (GTK_NOTEBOOK(notebook), t, new_label_with_icon(_("_Fonts"), _("Fonts"), icon_prefs_fonts, prefs));
 
-  // Colors
+  // default color theme's Colors
+  const PanColors& colors (PanColors::get());
+  const char* def_color_str (colors.def_bg.c_str());
+  const char* def_color_fg_str (colors.def_fg.c_str());
+
   row = 0;
   t = HIG :: workarea_create ();
   HIG :: workarea_add_section_title (t, &row, _("Header Pane"));
     HIG :: workarea_add_section_spacer(t, row, 6);
-    h = gtk_hbox_new (false, PAD);
+    h = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, PAD);
     pan_box_pack_start_defaults (GTK_BOX(h), gtk_label_new (_("Text:")));
-    pan_box_pack_start_defaults (GTK_BOX(h), new_color_button ("score-color-watched-fg", "black", prefs));
+    pan_box_pack_start_defaults (GTK_BOX(h), new_color_button ("score-color-watched-fg", def_color_str, prefs));
     pan_box_pack_start_defaults (GTK_BOX(h), gtk_label_new (_("Background:")));
     pan_box_pack_start_defaults (GTK_BOX(h), new_color_button ("score-color-watched-bg", TANGO_CHAMELEON_LIGHT, prefs));
     HIG :: workarea_add_row (t, &row, _("Scores of 9999 or more:"), h);
-    h = gtk_hbox_new (false, PAD);
+    h = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, PAD);
     pan_box_pack_start_defaults (GTK_BOX(h), gtk_label_new (_("Text:")));
-    pan_box_pack_start_defaults (GTK_BOX(h), new_color_button ("score-color-high-fg", "black", prefs));
+    pan_box_pack_start_defaults (GTK_BOX(h), new_color_button ("score-color-high-fg", def_color_str, prefs));
     pan_box_pack_start_defaults (GTK_BOX(h), gtk_label_new (_("Background:")));
     pan_box_pack_start_defaults (GTK_BOX(h), new_color_button ("score-color-high-bg", TANGO_BUTTER_LIGHT, prefs));
     HIG :: workarea_add_row (t, &row, _("Scores from 5000 to 9998:"), h);
-    h = gtk_hbox_new (false, PAD);
+    h = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, PAD);
     pan_box_pack_start_defaults (GTK_BOX(h), gtk_label_new (_("Text:")));
-    pan_box_pack_start_defaults (GTK_BOX(h), new_color_button ("score-color-medium-fg", "black", prefs));
+    pan_box_pack_start_defaults (GTK_BOX(h), new_color_button ("score-color-medium-fg", def_color_str, prefs));
     pan_box_pack_start_defaults (GTK_BOX(h), gtk_label_new (_("Background:")));
     pan_box_pack_start_defaults (GTK_BOX(h), new_color_button ("score-color-medium-bg", TANGO_SKY_BLUE_LIGHT, prefs));
     HIG :: workarea_add_row (t, &row, _("Scores from 1 to 4999:"), h);
-    h = gtk_hbox_new (false, PAD);
+    h = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, PAD);
     pan_box_pack_start_defaults (GTK_BOX(h), gtk_label_new (_("Text:")));
     pan_box_pack_start_defaults (GTK_BOX(h), new_color_button ("score-color-low-fg", TANGO_ALUMINUM_2, prefs));
     pan_box_pack_start_defaults (GTK_BOX(h), gtk_label_new (_("Background:")));
-    pan_box_pack_start_defaults (GTK_BOX(h), new_color_button ("score-color-low-bg", "black", prefs));
+    pan_box_pack_start_defaults (GTK_BOX(h), new_color_button ("score-color-low-bg", def_color_str, prefs));
     HIG :: workarea_add_row (t, &row, _("Scores from -9998 to -1:"), h);
-    h = gtk_hbox_new (false, PAD);
+    h = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, PAD);
     pan_box_pack_start_defaults (GTK_BOX(h), gtk_label_new (_("Text:")));
     pan_box_pack_start_defaults (GTK_BOX(h), new_color_button ("score-color-ignored-fg", TANGO_ALUMINUM_4, prefs));
     pan_box_pack_start_defaults (GTK_BOX(h), gtk_label_new (_("Background:")));
-    pan_box_pack_start_defaults (GTK_BOX(h), new_color_button ("score-color-ignored-bg", "black", prefs));
+    pan_box_pack_start_defaults (GTK_BOX(h), new_color_button ("score-color-ignored-bg", def_color_str, prefs));
     HIG :: workarea_add_row (t, &row, _("Scores of -9999 or less:"), h);
-    h = gtk_hbox_new (false, PAD);
+    h = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, PAD);
     pan_box_pack_start_defaults (GTK_BOX(h), gtk_label_new (_("Text:")));
     pan_box_pack_start_defaults (GTK_BOX(h), new_color_button ("color-read-fg", TANGO_ORANGE, prefs));
     pan_box_pack_start_defaults (GTK_BOX(h), gtk_label_new (_("Background:")));
-    pan_box_pack_start_defaults (GTK_BOX(h), new_color_button ("color-read-bg", "white", prefs));
-    HIG :: workarea_add_row (t, &row, _("Read collapsed thread:"), h);
+    pan_box_pack_start_defaults (GTK_BOX(h), new_color_button ("color-read-bg", def_color_str, prefs));
+    HIG :: workarea_add_row (t, &row, _("Collapsed thread with unread articles:"), h);
   HIG :: workarea_add_section_divider (t, &row);
   HIG :: workarea_add_section_title (t, &row, _("Body Pane"));
-    HIG :: workarea_add_section_spacer (t, row, 3);
-    h = gtk_hbox_new (false, PAD_SMALL);
+    HIG :: workarea_add_section_spacer (t, row, 5);
+    h = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, PAD_SMALL);
+    pan_box_pack_start_defaults (GTK_BOX(h), gtk_label_new (_("Text:")));
     pan_box_pack_start_defaults (GTK_BOX(h), new_color_button ("body-pane-color-quote-1", TANGO_CHAMELEON_DARK, prefs));
+    pan_box_pack_start_defaults (GTK_BOX(h), gtk_label_new (_("Background:")));
+    pan_box_pack_start_defaults (GTK_BOX(h), new_color_button ("body-pane-color-quote-1-bg", def_color_str, prefs));
+    HIG :: workarea_add_row (t, &row, _("First level of quoted text:"), h);
+    h = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, PAD_SMALL);
+    pan_box_pack_start_defaults (GTK_BOX(h), gtk_label_new (_("Text:")));
     pan_box_pack_start_defaults (GTK_BOX(h), new_color_button ("body-pane-color-quote-2", TANGO_ORANGE_DARK, prefs));
+    pan_box_pack_start_defaults (GTK_BOX(h), gtk_label_new (_("Background:")));
+    pan_box_pack_start_defaults (GTK_BOX(h), new_color_button ("body-pane-color-quote-2-bg", def_color_str, prefs));
+    HIG :: workarea_add_row (t, &row, _("Second level of quoted text:"), h);
+    h = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, PAD_SMALL);
+    pan_box_pack_start_defaults (GTK_BOX(h), gtk_label_new (_("Text:")));
     pan_box_pack_start_defaults (GTK_BOX(h), new_color_button ("body-pane-color-quote-3", TANGO_PLUM_DARK, prefs));
-    HIG :: workarea_add_row (t, &row, _("Quoted text:"), h);
-    HIG :: workarea_add_row (t, &row, _("URL:"), new_color_button ("body-pane-color-url", TANGO_SKY_BLUE_DARK, prefs));
-    HIG :: workarea_add_row (t, &row, _("Signature:"), new_color_button ("body-pane-color-signature", TANGO_SKY_BLUE_LIGHT, prefs));
+    pan_box_pack_start_defaults (GTK_BOX(h), gtk_label_new (_("Background:")));
+    pan_box_pack_start_defaults (GTK_BOX(h), new_color_button ("body-pane-color-quote-3-bg", def_color_str, prefs));
+    HIG :: workarea_add_row (t, &row, _("Third level of quoted text:"), h);
+    h = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, PAD_SMALL);
+    pan_box_pack_start_defaults (GTK_BOX(h), gtk_label_new (_("Text:")));
+    pan_box_pack_start_defaults (GTK_BOX(h), new_color_button ("body-pane-color-url", TANGO_SKY_BLUE_DARK, prefs));
+    pan_box_pack_start_defaults (GTK_BOX(h), gtk_label_new (_("Background:")));
+    pan_box_pack_start_defaults (GTK_BOX(h), new_color_button ("body-pane-color-url-bg", def_color_str, prefs)); //
+    HIG :: workarea_add_row (t, &row, _("URL:"), h);
+    h = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, PAD_SMALL);
+    pan_box_pack_start_defaults (GTK_BOX(h), gtk_label_new (_("Text:")));
+    pan_box_pack_start_defaults (GTK_BOX(h), new_color_button ("body-pane-color-signature", TANGO_SKY_BLUE_LIGHT, prefs));
+    pan_box_pack_start_defaults (GTK_BOX(h), gtk_label_new (_("Background:")));
+    pan_box_pack_start_defaults (GTK_BOX(h), new_color_button ("body-pane-color-signature-bg", def_color_str, prefs)); //
+    HIG :: workarea_add_row (t, &row, _("Signature:"), h);
+
+  HIG :: workarea_add_section_divider (t, &row);
+  HIG :: workarea_add_section_title (t, &row, _("Group Pane"));
+    HIG :: workarea_add_section_spacer (t, row, 1);
+    h = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, PAD_SMALL);
+    pan_box_pack_start_defaults (GTK_BOX(h), gtk_label_new (_("Text:")));
+    pan_box_pack_start_defaults (GTK_BOX(h), new_color_button ("group-pane-color-fg", def_color_fg_str, prefs));
+    pan_box_pack_start_defaults (GTK_BOX(h), gtk_label_new (_("Background:")));
+    pan_box_pack_start_defaults (GTK_BOX(h), new_color_button ("group-pane-color-bg", def_color_str, prefs)); //
+    HIG :: workarea_add_row (t, &row, _("Group Color:"), h);
+
+  // colors for others texts (score == 0 or body pane etc.... )
+  HIG :: workarea_add_section_divider (t, &row);
+  HIG :: workarea_add_section_title (t, &row, _("Other Text"));
+    h = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, PAD_SMALL);
+    pan_box_pack_start_defaults (GTK_BOX(h), gtk_label_new (_("Text:")));
+    pan_box_pack_start_defaults (GTK_BOX(h), new_color_button ("text-color-fg", def_color_fg_str, prefs));
+    pan_box_pack_start_defaults (GTK_BOX(h), gtk_label_new (_("Background:")));
+    pan_box_pack_start_defaults (GTK_BOX(h), new_color_button ("text-color-bg", def_color_str, prefs));
+    HIG :: workarea_add_row (t, &row, _("Text Color:"), h);
   HIG :: workarea_finish (t, &row);
+	
   gtk_notebook_append_page (GTK_NOTEBOOK(notebook), t, new_label_with_icon(_("_Colors"), _("Colors"), icon_prefs_colors, prefs));
 
   // Applications
@@ -1183,6 +1297,8 @@ PrefsDialog :: PrefsDialog (Prefs& prefs, GtkWindow* parent):
     HIG :: workarea_add_row (t, &row, _("_Mail reader:"), w);
     w = editor_new (prefs);
     HIG :: workarea_add_row (t, &row, _("_Text editor:"), w);
+    w = html_previewer_new (prefs);
+    HIG :: workarea_add_row (t, &row, _("_HTML previewer:"), w);
   HIG :: workarea_finish (t, &row);
   gtk_notebook_append_page (GTK_NOTEBOOK(notebook), t, new_label_with_icon(_("_Applications"), _("Applications"), icon_prefs_applications, prefs));
 
@@ -1207,21 +1323,24 @@ PrefsDialog :: PrefsDialog (Prefs& prefs, GtkWindow* parent):
 
   HIG :: workarea_finish (t, &row);
 
+  gtk_notebook_append_page (GTK_NOTEBOOK(notebook), t, new_label_with_icon(_("_Shortcuts"), _("Shortcuts"), icon_prefs_hotkeys, prefs));
+
   GtkWidget* scroll = gtk_scrolled_window_new (NULL, NULL);
-  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW(scroll), GTK_SHADOW_IN);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scroll),
                                   GTK_POLICY_AUTOMATIC,
-                                  GTK_POLICY_AUTOMATIC);
-  gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW(scroll), t);
+                                   GTK_POLICY_AUTOMATIC);
+  gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW(scroll), notebook);
+
+  GdkScreen* screen = gdk_screen_get_default ();
+  gtk_widget_set_size_request (scroll, gdk_screen_get_width(screen) - 400, gdk_screen_get_height(screen) - 200);
 
   gtk_widget_show_all (scroll);
 
-  gtk_notebook_append_page (GTK_NOTEBOOK(notebook), scroll, new_label_with_icon(_("_Shortcuts"), _("Shortcuts"), icon_prefs_hotkeys, prefs));
-
-  gtk_widget_show_all (notebook);
-  gtk_box_pack_start (GTK_BOX(gtk_dialog_get_content_area( GTK_DIALOG(dialog))), notebook, true, true, 0);
-
-  gtk_notebook_set_current_page(GTK_NOTEBOOK(notebook), 0);
+  gtk_box_pack_start (GTK_BOX(gtk_dialog_get_content_area( GTK_DIALOG(dialog))), scroll, true, true, 0);
 
   _root = dialog;
+
+  // initially set notebook to page 1 or last selected page from last visit
+  gtk_notebook_set_current_page(GTK_NOTEBOOK(notebook), prefs.get_int("prefs-last-selected-page",1));
+
 }
