@@ -32,7 +32,8 @@ ProgressView :: ProgressView ():
   _progress_status_idle_tag (0),
   _root (gtk_event_box_new ()),
   _progressbar (gtk_progress_bar_new ()),
-  _progress (0)
+  _progress (0),
+  _style (gtk_widget_get_style (_progressbar))
 {
   gtk_progress_bar_set_ellipsize (GTK_PROGRESS_BAR(_progressbar), PANGO_ELLIPSIZE_MIDDLE);
   gtk_container_add (GTK_CONTAINER(_root), _progressbar);
@@ -42,6 +43,12 @@ ProgressView :: ProgressView ():
 #endif
 }
 
+ProgressView :: ~ProgressView ()
+{
+   set_progress(0);
+   g_object_unref (_style);
+}
+
 void
 ProgressView :: set_progress (Progress * progress)
 {
@@ -129,3 +136,18 @@ ProgressView :: update_text_soon ()
   if (!_progress_status_idle_tag)
        _progress_status_idle_tag = g_timeout_add (333, on_progress_status_idle, this);
 }
+
+void ProgressView :: set_color (const std::string& color)
+{
+  GtkStyle* style = gtk_style_copy (_style);
+
+  gdk_color_parse (color.c_str(), &style->bg[GTK_STATE_PRELIGHT]);
+  gtk_widget_set_style (_progressbar, style);
+  g_object_unref (style);
+
+}
+
+void ProgressView :: reset_color ()
+{
+    gtk_widget_set_style (_progressbar, NULL);
+}
