@@ -26,7 +26,7 @@
 #include <pan/data/article.h>
 #include <pan/data/article-cache.h>
 #include <pan/data/data.h>
-#include <gtk/gtkwindow.h>
+#include "gtk-compat.h"
 #include "group-prefs.h"
 #include "prefs.h"
 
@@ -71,5 +71,5 @@ namespace pan
       static bool _save_text;
       static bool _save_attachments;
   };
-} 
+}
 #endif
