@@ -50,6 +50,7 @@ enum
 void
 TaskPane :: get_selected_tasks_foreach (GtkTreeModel *model, GtkTreePath *, GtkTreeIter *iter, gpointer list_g)
 {
+
   Task * task (0);
   gtk_tree_model_get (model, iter, COL_TASK_POINTER, &task, -1);
   static_cast<tasks_t*>(list_g)->push_back (task);
@@ -103,6 +104,67 @@ namespace
   }
 }
 
+namespace
+{
+  bool fill_task_info (Task* task, char* buffer, size_t size)
+  {
+
+    EvolutionDateMaker date_maker;
+    char * date(0);
+    TaskUpload * tu (dynamic_cast<TaskUpload*>(task));
+
+    if (tu)
+    {
+      const Article& a(tu->get_article());
+      date = date_maker.get_date_string (tu->get_article().time_posted);
+      g_snprintf(buffer,size,
+                 _("\n<u>Upload</u>\n\n<i>Subject:</i> <b>\"%s\"</b>\n<i>From:</i> <b>%s</b>\n"
+                   "<i>Groups:</i> <b>%s</b>\n<i>Sourcefile:</i> <b>%s</b>\n"),
+                 escaped(a.subject.to_string()).c_str(), escaped(a.author.to_string()).c_str(),
+                 tu->get_groups().c_str(), tu->get_filename().c_str());
+    }
+
+    TaskArticle * ta (dynamic_cast<TaskArticle*>(task));
+    if (ta)
+    {
+      const Article& a(ta->get_article());
+      date = date_maker.get_date_string (ta->get_article().time_posted);
+      g_snprintf(buffer, size,
+                 _("\n<u>Download</u>\n\n<i>Subject:</i> <b>\"%s\"</b>\n<i>From:</i> <b>%s</b>\n<i>Date:</i> <b>%s</b>\n"
+                   "<i>Groups:</i> <b>%s</b>\n<i>Save Path:</i> <b>%s</b>\n"),
+                 escaped(a.subject.to_string()).c_str(), escaped(a.author.to_string()).c_str(), date ? date : _("unknown"),
+                 ta->get_groups().c_str(), ta->get_save_path().to_string().c_str());
+    }
+
+    g_free (date);
+
+    return tu || ta;
+  }
+
+}
+
+void
+TaskPane :: show_task_info(const tasks_t& tasks)
+{
+  
+  if (tasks.size() == 0) return;  
+  Task* task (tasks.front());
+  if (!task) return;
+
+  char buffer[4096];
+  const bool task_found (fill_task_info (task, buffer, sizeof(buffer)));
+
+  GtkWidget * w = gtk_message_dialog_new_with_markup (
+      GTK_WINDOW (gtk_widget_get_toplevel (_root)),
+      GTK_DIALOG_DESTROY_WITH_PARENT,
+      GTK_MESSAGE_INFO,
+      GTK_BUTTONS_CLOSE,
+        buffer, NULL);
+  g_signal_connect_swapped (w, "response", G_CALLBACK (gtk_widget_destroy), w);
+  gtk_widget_show_all (w);
+
+}
+
 gboolean
 TaskPane:: on_tooltip_query(GtkWidget  *widget,
                             gint        x,
@@ -113,6 +175,8 @@ TaskPane:: on_tooltip_query(GtkWidget  *widget,
 {
   TaskPane* tp(static_cast<TaskPane*>(data));
 
+  if (!tp->_prefs.get_flag("show-taskpane-popups", true)) return false;
+
   gtk_tooltip_set_icon_from_stock (tooltip, GTK_STOCK_DIALOG_INFO, GTK_ICON_SIZE_DIALOG);
 
   GtkTreeIter iter;
@@ -120,45 +184,15 @@ TaskPane:: on_tooltip_query(GtkWidget  *widget,
   GtkTreeModel *model = gtk_tree_view_get_model (tree_view);
   GtkTreePath *path(0);
 
-  char buffer[4096];
-  Task * task(0);
-  bool task_found(false);
-
   if (!gtk_tree_view_get_tooltip_context (tree_view, &x, &y, keyboard_tip, &model, &path, &iter))
     return false;
 
+  Task * task(0);
   gtk_tree_model_get (model, &iter, COL_TASK_POINTER, &task, -1);
 
+  char buffer[4096];
   g_snprintf(buffer,sizeof(buffer),"...");
-
-  EvolutionDateMaker date_maker;
-  char * date(0);
-
-  TaskUpload * tu (dynamic_cast<TaskUpload*>(task));
-  if (tu)
-  {
-    const Article& a(tu->get_article());
-    date = date_maker.get_date_string (tu->get_article().time_posted);
-    g_snprintf(buffer,sizeof(buffer),
-               _("\n<u>Upload</u>\n\n<i>Subject:</i> <b>\"%s\"</b>\n<i>From:</i> <b>%s</b>\n"
-                 "<i>Groups:</i> <b>%s</b>\n<i>Sourcefile:</i> <b>%s</b>\n"),
-               a.subject.to_string().c_str(), escaped(a.author.to_string()).c_str(),
-               tu->get_groups().c_str(), tu->get_filename().c_str());
-  }
-
-  TaskArticle * ta (dynamic_cast<TaskArticle*>(task));
-  if (ta)
-  {
-    const Article& a(ta->get_article());
-    date = date_maker.get_date_string (ta->get_article().time_posted);
-    g_snprintf(buffer,sizeof(buffer),
-               _("\n<u>Download</u>\n\n<i>Subject:</i> <b>\"%s\"</b>\n<i>From:</i> <b>%s</b>\n<i>Date:</i> <b>%s</b>\n"
-                 "<i>Groups:</i> <b>%s</b>\n<i>Save Path:</i> <b>%s</b>\nPaused: %d"),
-               a.subject.to_string().c_str(), escaped(a.author.to_string()).c_str(), date ? date : _("unknown"),
-               ta->get_groups().c_str(), ta->get_save_path().to_string().c_str(), ta->start_paused());
-  }
-
-  task_found = tu || ta;
+  const bool task_found (fill_task_info (task, buffer, sizeof(buffer)));
 
   if (task_found)
   {
@@ -167,8 +201,6 @@ TaskPane:: on_tooltip_query(GtkWidget  *widget,
   }
   gtk_tree_path_free (path);
 
-  g_free (date);
-
   return true;
 }
 
@@ -220,6 +252,10 @@ void TaskPane :: online_toggled_cb (GtkToggleButton* b, Queue *queue)
 {
   queue->set_online (gtk_toggle_button_get_active (b));
 }
+void TaskPane :: popup_toggled_cb (GtkToggleButton* b, TaskPane* pane)
+{
+  pane->_prefs.set_flag("show-taskpane-popups", gtk_toggle_button_get_active(b));
+}
 void TaskPane :: up_clicked_cb (GtkButton*, TaskPane* pane)
 {
   pane->_queue.move_up (pane->get_selected_tasks());
@@ -236,6 +272,10 @@ void TaskPane :: bottom_clicked_cb (GtkButton*, TaskPane* pane)
 {
   pane->_queue.move_bottom (pane->get_selected_tasks());
 }
+void TaskPane :: show_info_clicked_cb (GtkButton*, TaskPane* pane)
+{
+  pane->show_task_info (pane->get_selected_tasks());
+}
 void TaskPane :: stop_clicked_cb (GtkButton*, TaskPane* pane)
 {
   pane->_queue.stop_tasks (pane->get_selected_tasks());
@@ -624,6 +664,7 @@ namespace
   void do_move_down      (GtkAction*, gpointer p)  { static_cast<TaskPane*>(p)->down_clicked_cb(0, static_cast<TaskPane*>(p)); }
   void do_move_top       (GtkAction*, gpointer p)  { static_cast<TaskPane*>(p)->top_clicked_cb(0, static_cast<TaskPane*>(p)); }
   void do_move_bottom    (GtkAction*, gpointer p)  { static_cast<TaskPane*>(p)->bottom_clicked_cb(0, static_cast<TaskPane*>(p)); }
+  void do_show_info      (GtkAction*, gpointer p)  { static_cast<TaskPane*>(p)->show_info_clicked_cb(0, static_cast<TaskPane*>(p)); }
   void do_stop           (GtkAction*, gpointer p)  { static_cast<TaskPane*>(p)->stop_clicked_cb(0, static_cast<TaskPane*>(p)); }
   void do_delete         (GtkAction*, gpointer p)  { static_cast<TaskPane*>(p)->delete_clicked_cb(0, static_cast<TaskPane*>(p)); }
   void do_restart        (GtkAction*, gpointer p)  { static_cast<TaskPane*>(p)->restart_clicked_cb(0, static_cast<TaskPane*>(p)); }
@@ -652,6 +693,11 @@ namespace
       N_("Move To Bottom"),
       G_CALLBACK(do_move_bottom) },
 
+    { "show-info", NULL,
+      N_("Show Task Information"), "",
+      N_("Show Task Information"),
+      G_CALLBACK(do_show_info) },
+
     { "stop", NULL,
       N_("Stop Task"), "",
       N_("Stop Task"),
@@ -713,54 +759,314 @@ namespace
   }
 }
 
-TaskPane :: TaskPane (Queue& queue, Prefs& prefs): _queue(queue)
+namespace
+{
+  // the text typed by the user.
+  std::string search_text;
+
+  guint entry_changed_tag (0u);
+  guint activate_soon_tag (0u);
+
+  // AUTHOR, SUBJECT, SUBJECT_OR_AUTHOR, or MESSAGE_ID
+  int search_mode;
+
+  void set_search_entry (GtkWidget * entry, const char * s)
+  {
+    g_signal_handler_block (entry, entry_changed_tag);
+    gtk_entry_set_text (GTK_ENTRY(entry), s);
+    g_signal_handler_unblock (entry, entry_changed_tag);
+  }
+
+  gboolean search_entry_focus_in_cb (GtkWidget     * w,
+                                     GdkEventFocus * ,
+                                     gpointer        )
+  {
+#if !GTK_CHECK_VERSION(3,0,0)
+    gtk_widget_modify_text (w, GTK_STATE_NORMAL, NULL); // resets
+#else
+    gtk_widget_override_color (w, GTK_STATE_FLAG_NORMAL, NULL);
+#endif
+    set_search_entry (w, search_text.c_str());
+    return false;
+  }
+
+  const char * mode_strings [] =
+  {
+    N_("Subject or Author"),
+    N_("Sub or Auth (regex)"),
+    N_("Subject"),
+    N_("Author"),
+    N_("Message-ID"),
+  };
+
+  enum
+  {
+    SUBJECT_OR_AUTHOR=0,
+    SUBJECT_OR_AUTHOR_REGEX=1,
+    SUBJECT=2,
+    AUTHOR=3,
+    MESSAGE_ID=4
+  };
+
+  void refresh_search_entry (GtkWidget * w)
+  {
+    if (search_text.empty() && !gtk_widget_has_focus(w))
+    {
+#if !GTK_CHECK_VERSION(3,0,0)
+      GdkColor c;
+      c.pixel = 0;
+      c.red = c.green = c.blue = 0xAAAA;
+      gtk_widget_modify_text (w, GTK_STATE_NORMAL, &c);
+#else
+      GdkRGBA c;
+      gdk_rgba_parse (&c, "0xAAA");
+      gtk_widget_override_color(w, GTK_STATE_FLAG_NORMAL, &c);
+#endif
+      set_search_entry (w, _(mode_strings[search_mode]));
+    }
+  }
+
+  gboolean search_entry_focus_out_cb (GtkWidget     * w,
+                                      GdkEventFocus * ,
+                                      gpointer        )
+  {
+    refresh_search_entry (w);
+    return false;
+  }
+
+  void search_activate (TaskPane * h)
+  {
+    h->filter (search_text, search_mode);
+  }
+
+  void remove_activate_soon_tag ()
+  {
+    if (activate_soon_tag != 0)
+    {
+      g_source_remove (activate_soon_tag);
+      activate_soon_tag = 0;
+    }
+  }
+
+  void search_entry_activated (GtkEntry *, gpointer h_gpointer)
+  {
+    search_activate (static_cast<TaskPane*>(h_gpointer));
+    remove_activate_soon_tag ();
+  }
+
+  gboolean activated_timeout_cb (gpointer h_gpointer)
+  {
+    search_activate (static_cast<TaskPane*>(h_gpointer));
+    remove_activate_soon_tag ();
+    return false; // remove the source
+  }
+
+  // ensure there's exactly one activation timeout
+  // and that it's set to go off in a half second from now.
+  void bump_activate_soon_tag (TaskPane * h)
+  {
+    remove_activate_soon_tag ();
+    activate_soon_tag = g_timeout_add (500, activated_timeout_cb, h);
+  }
+
+  // when the user changes the filter text,
+  // update our state variable and bump the activate timeout.
+  void search_entry_changed (GtkEditable * e, gpointer h_gpointer)
+  {
+    search_text = gtk_entry_get_text (GTK_ENTRY(e));
+    bump_activate_soon_tag (static_cast<TaskPane*>(h_gpointer));
+    refresh_search_entry (GTK_WIDGET(e));
+  }
+
+  // when the search mode is changed via the menu,
+  // update our state variable and bump the activate timeout.
+  void search_menu_toggled_cb (GtkCheckMenuItem  * menu_item,
+                                gpointer            entry_g)
+  {
+    if (gtk_check_menu_item_get_active  (menu_item))
+    {
+      search_mode = GPOINTER_TO_INT (g_object_get_data (G_OBJECT(menu_item), "MODE"));
+      refresh_search_entry (GTK_WIDGET(entry_g));
+      TaskPane * h = (TaskPane*) g_object_get_data (G_OBJECT(entry_g), "pane");
+      bump_activate_soon_tag (h);
+    }
+  }
+
+  void entry_icon_release (GtkEntry*, GtkEntryIconPosition icon_pos, GdkEventButton*, gpointer menu)
+  {
+    if (icon_pos == GTK_ENTRY_ICON_PRIMARY)
+      gtk_menu_popup (GTK_MENU(menu), 0, 0, 0, 0, 0, gtk_get_current_event_time());
+  }
+
+  void entry_icon_release_2 (GtkEntry *entry, GtkEntryIconPosition icon_pos, GdkEventButton*, gpointer pane_gpointer)
+  {
+    if (icon_pos == GTK_ENTRY_ICON_SECONDARY) {
+      set_search_entry (GTK_WIDGET(entry), "");
+      refresh_search_entry (GTK_WIDGET(entry));
+      search_text.clear ();
+      search_entry_activated (NULL, pane_gpointer);
+    }
+  }
+
+  gboolean filter_visible_func (GtkTreeModel *model, GtkTreeIter *iter, gpointer gdata)
+  {
+
+     if (search_text.empty()) return true;
+
+     Task *task(0);
+     /* Get value from column */
+     gtk_tree_model_get( GTK_TREE_MODEL(model), iter, COL_TASK_POINTER, &task, -1 );
+
+     TaskArticle* ta (dynamic_cast<TaskArticle*>(task));
+
+/*  SUBJECT_OR_AUTHOR=0,
+    SUBJECT_OR_AUTHOR_REGEX=1,
+    SUBJECT=2,
+    AUTHOR=3,
+    MESSAGE_ID=4
+*/
+     if (ta)
+     {
+       std::string s1("");
+       if (search_mode == 0)
+       {
+        s1 = ta->get_article().author.c_str();
+        if (s1.find(search_text) != s1.npos) return true;
+        s1 = ta->get_article().subject.c_str();
+       }
+       if (search_mode == 1)
+       {
+          GRegexCompileFlags cf0((GRegexCompileFlags)0);
+          GRegexMatchFlags mf0((GRegexMatchFlags)0);
+          GRegex* rex = g_regex_new (search_text.c_str(), cf0, mf0, NULL);
+          if (!rex) return false;
+          const bool match =
+            g_regex_match (rex, ta->get_article().subject.c_str(), G_REGEX_MATCH_NOTEMPTY, NULL) ||
+            g_regex_match (rex, ta->get_article().author.c_str(), G_REGEX_MATCH_NOTEMPTY, NULL);
+          g_regex_unref(rex);
+          return match;
+       }
+       if (search_mode == 2)
+        s1 = ta->get_article().subject.c_str();
+       if (search_mode == 3)
+        s1 = ta->get_article().author.c_str();
+       if (search_mode == 4)
+        s1 = ta->get_article().message_id.c_str();
+
+       if (s1.find(search_text) != s1.npos) return true;
+     }
+
+     return false;
+
+  }
+}
+
+void
+TaskPane :: filter (const std::string& text, int mode)
+{
+  search_text = text;
+  search_mode = mode;
+  gtk_tree_model_filter_refilter (GTK_TREE_MODEL_FILTER(gtk_tree_view_get_model(GTK_TREE_VIEW(_view))));
+}
+
+GtkWidget*
+TaskPane :: create_filter_entry ()
+{
+  GtkWidget * entry = gtk_entry_new ();
+//  _action_manager.disable_accelerators_when_focused (entry);
+  g_object_set_data (G_OBJECT(entry), "pane", this);
+  g_signal_connect (entry, "focus-in-event", G_CALLBACK(search_entry_focus_in_cb), NULL);
+  g_signal_connect (entry, "focus-out-event", G_CALLBACK(search_entry_focus_out_cb), NULL);
+  g_signal_connect (entry, "activate", G_CALLBACK(search_entry_activated), this);
+  entry_changed_tag = g_signal_connect (entry, "changed", G_CALLBACK(search_entry_changed), this);
+
+  gtk_entry_set_icon_from_stock( GTK_ENTRY( entry ),
+                                 GTK_ENTRY_ICON_PRIMARY,
+                                 GTK_STOCK_FIND);
+  gtk_entry_set_icon_from_stock( GTK_ENTRY( entry ),
+                                 GTK_ENTRY_ICON_SECONDARY,
+                                 GTK_STOCK_CLEAR );
+
+  bool regex = _prefs.get_flag ("use-regex", false);
+  GtkWidget * menu = gtk_menu_new ();
+  if (regex == true )
+    search_mode = 1;
+  else
+    search_mode = 0;
+  GSList * l = 0;
+  for (int i=0, qty=G_N_ELEMENTS(mode_strings); i<qty; ++i) {
+    GtkWidget * w = gtk_radio_menu_item_new_with_label (l, _(mode_strings[i]));
+    l = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM(w));
+    g_object_set_data (G_OBJECT(w), "MODE", GINT_TO_POINTER(i));
+    g_signal_connect (w, "toggled", G_CALLBACK(search_menu_toggled_cb),entry);
+    if (search_mode == i)
+      gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(w), TRUE);
+    gtk_menu_shell_append (GTK_MENU_SHELL(menu), w);
+    gtk_widget_show (w);
+  }
+  g_signal_connect (entry, "icon-release", G_CALLBACK(entry_icon_release), menu);
+  g_signal_connect (entry, "icon-release", G_CALLBACK(entry_icon_release_2), this);
+
+  refresh_search_entry (entry);
+
+  return entry;
+}
+
+TaskPane :: TaskPane (Queue& queue, Prefs& prefs): _queue(queue), _prefs(prefs)
 {
   _root = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 
   GtkWidget * w;
 
-  GtkWidget * vbox = gtk_vbox_new (false, 0);
+  GtkWidget * vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 
-    GtkWidget * buttons = gtk_hbox_new (false, PAD_SMALL);
+    GtkWidget * buttons = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, PAD_SMALL);
 
     w = _online_toggle = gtk_check_button_new ();
     _online_toggle_handler = g_signal_connect (w, "clicked", G_CALLBACK(online_toggled_cb), &queue);
     GtkWidget * i = _online_image = gtk_image_new ();
     GtkWidget * l = gtk_label_new_with_mnemonic (_("_Online"));
-    GtkWidget * v = gtk_hbox_new (false, PAD);
+    GtkWidget * v = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, PAD);
     gtk_label_set_mnemonic_widget (GTK_LABEL(l), w);
     on_queue_online_changed (queue, queue.is_online());
     gtk_box_pack_start (GTK_BOX(v), i, 0, 0, 0);
     gtk_box_pack_start (GTK_BOX(v), l, 0, 0, 0);
     gtk_container_add (GTK_CONTAINER(w), v);
     gtk_box_pack_start (GTK_BOX(buttons), w, false, false, 0);
-    gtk_box_pack_start (GTK_BOX(buttons), gtk_vseparator_new(), 0, 0, 0);
+    gtk_box_pack_start (GTK_BOX(buttons), gtk_separator_new(GTK_ORIENTATION_VERTICAL), 0, 0, 0);
 
     add_button (buttons, GTK_STOCK_GO_UP, G_CALLBACK(up_clicked_cb), this);
     add_button (buttons, GTK_STOCK_GOTO_TOP, G_CALLBACK(top_clicked_cb), this);
-    gtk_box_pack_start (GTK_BOX(buttons), gtk_vseparator_new(), 0, 0, 0);
+    gtk_box_pack_start (GTK_BOX(buttons), gtk_separator_new(GTK_ORIENTATION_VERTICAL), 0, 0, 0);
     add_button (buttons, GTK_STOCK_GO_DOWN, G_CALLBACK(down_clicked_cb), this);
     add_button (buttons, GTK_STOCK_GOTO_BOTTOM, G_CALLBACK(bottom_clicked_cb), this);
-    gtk_box_pack_start (GTK_BOX(buttons), gtk_vseparator_new(), 0, 0, 0);
+    gtk_box_pack_start (GTK_BOX(buttons), gtk_separator_new(GTK_ORIENTATION_VERTICAL), 0, 0, 0);
     w = add_button (buttons, GTK_STOCK_REDO, G_CALLBACK(restart_clicked_cb), this);
     gtk_widget_set_tooltip_text( w, _("Restart Tasks"));
     w = add_button (buttons, GTK_STOCK_STOP, G_CALLBACK(stop_clicked_cb), this);
     gtk_widget_set_tooltip_text( w, _("Stop Tasks"));
     w = add_button (buttons, GTK_STOCK_DELETE, G_CALLBACK(delete_clicked_cb), this);
     gtk_widget_set_tooltip_text( w, _("Delete Tasks"));
-    gtk_box_pack_start (GTK_BOX(buttons), gtk_vseparator_new(), 0, 0, 0);
+    gtk_box_pack_start (GTK_BOX(buttons), gtk_separator_new(GTK_ORIENTATION_VERTICAL), 0, 0, 0);
     w = add_button (buttons, GTK_STOCK_CLOSE, 0, 0);
     g_signal_connect_swapped (w, "clicked", G_CALLBACK(gtk_widget_destroy), _root);
+    w = _popup_toggle = gtk_check_button_new ();
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(w), _prefs.get_flag("show-taskpane-popups", true));
+    l = gtk_label_new_with_mnemonic (_("Show popups"));
+    v = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, PAD);
+    gtk_box_pack_start (GTK_BOX(v), l, 0, 0, 0);
+    gtk_container_add (GTK_CONTAINER(w), v);
+    g_signal_connect (w, "clicked", G_CALLBACK(popup_toggled_cb), this);
+    gtk_box_pack_start (GTK_BOX(buttons), w, false, false, 0);
     pan_box_pack_start_defaults (GTK_BOX(buttons), gtk_event_box_new()); // eat horizontal space
 
   gtk_box_pack_start (GTK_BOX(vbox), buttons, false, false, 0);
-  gtk_box_pack_start (GTK_BOX(vbox), gtk_hseparator_new(), false, false, 0);
+  gtk_box_pack_start (GTK_BOX(vbox), gtk_separator_new(GTK_ORIENTATION_HORIZONTAL), false, false, 0);
 
   // statusbar
-  GtkWidget * hbox = gtk_hbox_new (false, PAD);
+  GtkWidget * hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, PAD);
   w = _status_label = gtk_label_new (0);
   gtk_box_pack_start (GTK_BOX(hbox), w, false, false, PAD_SMALL);
-  gtk_box_pack_start (GTK_BOX(vbox), hbox, false, false, PAD);
 
   _store = gtk_list_store_new (NUM_COLS, G_TYPE_POINTER, G_TYPE_INT);
   _view = gtk_tree_view_new_with_model (GTK_TREE_MODEL(_store));
@@ -785,6 +1091,17 @@ TaskPane :: TaskPane (Queue& queue, Prefs& prefs): _queue(queue)
   add_actions(_view);
   gtk_window_add_accel_group (GTK_WINDOW(_root), gtk_ui_manager_get_accel_group (_uim));
 
+  // search filter
+  gtk_box_pack_start (GTK_BOX(hbox), gtk_separator_new(GTK_ORIENTATION_VERTICAL), 0, 0, 0);
+  gtk_box_pack_start (GTK_BOX(hbox), create_filter_entry(), false, false, PAD);
+  GtkTreeModel* initial_model= gtk_tree_view_get_model(GTK_TREE_VIEW( _view ));
+  GtkTreeModel* filter_model = gtk_tree_model_filter_new( initial_model, NULL );
+  gtk_tree_model_filter_set_visible_func (GTK_TREE_MODEL_FILTER ( filter_model ),(GtkTreeModelFilterVisibleFunc) filter_visible_func, NULL, NULL);
+  gtk_tree_view_set_model( GTK_TREE_VIEW( _view ),filter_model);
+  g_object_unref( filter_model );
+
+  gtk_box_pack_start (GTK_BOX(vbox), hbox, false, false, PAD);
+
   w = gtk_scrolled_window_new (NULL, NULL);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW(w), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
   gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW(w), GTK_SHADOW_IN);
