@@ -23,6 +23,7 @@ extern "C" {
 }
 #include "task-post.h"
 #include <pan/general/debug.h>
+#include <pan/general/log.h>
 
 using namespace pan;
 
@@ -32,7 +33,7 @@ namespace
   {
     char buf[1024];
     snprintf (buf, sizeof(buf), _("Posting \"%s\""), g_mime_message_get_subject(message));
-    return std::string (buf);
+    return buf;
   }
 }
 
@@ -68,9 +69,17 @@ TaskPost :: on_nntp_done (NNTP              * nntp,
 {
   _state.set_health (health);
 
-  if (health == ERR_NETWORK)
+  const char* res(g_mime_message_get_subject(_message));
+
+  if (health == ERR_NETWORK || health == ERR_COMMAND)
+  {
+    Log :: add_err_va (_("Posting of \"%s\" failed: %s"),
+                          res, response.str);
     _state.set_need_nntp (_server);
+  }
   else {
+    Log :: add_info_va (_("Posting of \"%s\" successful: %s"),
+                          res, response.str);
     _state.set_completed ();
     set_error (response);
     set_finished (health);
