@@ -105,7 +105,6 @@ TaskUpload :: TaskUpload (const std::string         & filename,
   _queue_pos(0),
   _msg (msg),
   _first(true),
-  _paused(true),
   _groups(get_groups_str(article))
 {
 
@@ -115,8 +114,7 @@ TaskUpload :: TaskUpload (const std::string         & filename,
   struct stat sb;
   stat(filename.c_str(),&sb);
   _bytes = sb.st_size;
-
-  _state.set_paused();
+  _state.set_initial();
 }
 
 namespace
@@ -176,9 +174,6 @@ TaskUpload :: update_work (NNTP* checkin_pending)
   }
   else if (_encoder_has_run && !_needed.empty())
   {
-    // DBG
-//     _state.set_completed();
-//     set_finished(_queue_pos);
     _state.set_need_nntp(_server);
   }
   else if (_needed.empty())
@@ -345,14 +340,14 @@ TaskUpload :: on_nntp_done (NNTP * nntp,
         else
         {
           g_snprintf(buf,sizeof(buf), _("Posting of file %s not completely successful: Check the log (right-click list item)."),
-                 _basename.c_str(), response.str);
+                 _basename.c_str());
           tmp.severity = Log :: PAN_SEVERITY_ERROR;
         }
         tmp.message = buf;
         Log::add_entry_list (tmp, _logfile);
         _logfile.clear();
       }
-
+      break;
     case TOO_MANY_CONNECTIONS:
       // lockout for 120 secs, but try
       it->second.reset();
@@ -379,7 +374,6 @@ TaskUpload :: on_nntp_done (NNTP * nntp,
 unsigned long
 TaskUpload :: get_bytes_remaining () const
 {
-  if (_paused) return _bytes*1.15;
   unsigned long bytes (0);
   foreach_const (needed_t, _needed, it)
     bytes += (unsigned long)it->second.bytes;
