@@ -26,6 +26,7 @@ using namespace pan;
 
 Task :: Task (const Quark& type, const StringView& description): Progress(description), _type(type)
 {
+  verbose (_description);
 }
 
 Task :: ~Task ()
@@ -70,11 +71,26 @@ Task :: give_decoder (DecoderSource* s, Decoder* d)
   _decoder_to_source[d] = s;
   use_decoder (d);
 }
+
+void
+Task :: give_encoder (EncoderSource* s, Encoder* d)
+{
+  _encoder_to_source[d] = s;
+  use_encoder (d);
+}
+
 void
 Task :: use_decoder (Decoder * d UNUSED)
 {
-  abort ();
+  assert(0 && "oops, child class task.cc called!\n");
 }
+
+void
+Task :: use_encoder (Encoder * d UNUSED)
+{
+  assert(0 && "oops, child class task.cc called!\n");
+}
+
 void
 Task :: check_in (Decoder * d)
 {
@@ -87,3 +103,16 @@ Task :: check_in (Decoder * d)
     s->check_in (d, this);
   }
 }
+
+void
+Task :: check_in (Encoder * d)
+{
+  encoder_to_source_t::iterator it (_encoder_to_source.find (d));
+
+  if (it != _encoder_to_source.end())
+  {
+    EncoderSource * s (it->second);
+    _encoder_to_source.erase (d);
+    s->check_in (d, this);
+  }
+}
