@@ -56,11 +56,6 @@
 #define YENC_SHIFT             42
 #define YENC_QUOTE_SHIFT       64
 
-#define HTML_MARKER_BEGIN         "<html>"
-#define HTML_MARKER_BEGIN_LEN     6
-#define HTML_MARKER_END           "</html>"
-#define HTML_MARKER_END_LEN       7
-
 #define NEEDS_DECODING(encoding) ((encoding == GMIME_CONTENT_ENCODING_BASE64) ||   \
                                  (encoding == GMIME_CONTENT_ENCODING_QUOTEDPRINTABLE))
 
@@ -69,7 +64,7 @@ namespace pan
 
 #ifdef HAVE_GMIME_CRYPTO
   GMimeMessage* message_add_signed_part (const std::string& uid, const std::string& body_str, GMimeMessage* body);
-  GMimeMessage* gpg_encrypt (const std::string& uid, const std::string& body_str, GMimeMessage* body, GPtrArray* rcp, bool sign);
+  bool gpg_encrypt (const std::string& uid, const std::string& body_str, GMimeMessage* body, GPtrArray* rcp, bool sign);
   bool gpg_verify_mps (GMimeObject*, GPGDecErr&);
 #endif
   /**
@@ -113,7 +108,7 @@ namespace pan
 
   char *pan_g_mime_message_get_body (GMimeMessage *message, gboolean *is_html);
   void pan_g_mime_message_add_recipients_from_string (GMimeMessage *message, GMimeRecipientType type, const char *string);
-  void pan_g_mime_message_set_message_id (GMimeMessage *msg, const char *mid);
+  std::string pan_g_mime_message_set_message_id (GMimeMessage *msg, const char *mid);
 
   extern iconv_t conv;
   extern bool iconv_inited;
